@@ -222,11 +222,12 @@ def eliminate_empty(data: list):
 
 
 def find_child(data, key="id", parent_key="parent_id"):
+    new_data = deepcopy(data)
     result = []
     obj = {}
-    for x in data:
+    for x in new_data:
         obj[x.get(key)] = x
-    for x in data:
+    for x in new_data:
         parent_key_value = x.get(parent_key)
         parent = obj.get(parent_key_value, {})
         if parent:
@@ -277,6 +278,10 @@ def sort_dfs(data, sort_key="serial_index", children_key="children", reverse=Fal
                     sort_dfs(sub_element, sort_key=sort_key, children_key=children_key, reverse=reverse)
 
 
+def sort_tree(data, sort_key="serial_index", children_key="children", reverse=False):
+    sort_dfs(data, sort_key=sort_key, children_key=children_key, reverse=reverse)
+
+
 def tree2list(data_tree, key="children", parent_key="parent_key", data_key="key"):
     data_tree_tmp = copy.deepcopy(data_tree)
     data = []
@@ -295,3 +300,20 @@ def tree2list(data_tree, key="children", parent_key="parent_key", data_key="key"
     elif isinstance(data_tree_tmp, dict):
         temp(data_tree, parent_key)
     return data
+
+
+def sort_dict_list_by_list(dict_list: List[dict], sort_value_list: List[str], name_key="name"):
+    """
+    根据sort_value_list的顺序重新排列dict_list中的字典顺序。
+
+    :param name_key:
+    :param dict_list: List[Dict] - 包含字典的列表，每个字典都有一个排序属性
+    :param sort_value_list: List[str] - 包含字符串的列表，字符串对应dict_list中排序属性
+    """
+    # 创建一个字典，根据name属性快速查找对应的字典
+    name_to_dict = {d[name_key]: d for d in dict_list}
+
+    # 根据name_list的顺序重新排列字典
+    ordered_list = [name_to_dict[name] for name in sort_value_list if name in name_to_dict]
+
+    return ordered_list
